#ifndef HYAKUTYPING_H
#define HYAKUTYPING_H

/*!
  \file
  \brief Sl^CsO

  \author Satofumi KAMIMURA

  $Id$

  \todo OpenGL łŃL[͂Ȃ̂AȂƂ
*/


// A
#ifndef BUG_ADDRESS
#define BUG_ADDRESS "satofumi@sourceforge.jp" //!< oOA
#endif


// o[W
#ifndef VERSION
#define VERSION "X.X.X"         //!< o[W
#endif
const char*const VersionText = "version " VERSION; //!< o[W


// lbg[N
enum {
  ServerPort = 57577,          //!< lbg[Nΐp̐ڑ|[gԍ
};

#endif /* !HYAKUTYPING_H */
